summaryrefslogtreecommitdiffstats
path: root/src/parsers/search.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/parsers/search.cpp')
-rw-r--r--src/parsers/search.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/parsers/search.cpp b/src/parsers/search.cpp
index 0d0a952..5fd6b22 100644
--- a/src/parsers/search.cpp
+++ b/src/parsers/search.cpp
@@ -18,11 +18,11 @@
namespace Parsers
{
/** Parses the output of apt-cache search */
-void Search::operator() (AptProtocol* slave, const QString& tag, const QString& value)
+void Search::operator() (AptProtocol* slave, const TQString& tag, const TQString& value)
{
- static QMap<QString, QString> results;
- static QString cur_package;
- static QString query;
+ static TQMap<TQString, TQString> results;
+ static TQString cur_package;
+ static TQString query;
if (tag == "begin")
{
@@ -42,16 +42,16 @@ void Search::operator() (AptProtocol* slave, const QString& tag, const QString&
{
// We separate results whose package name matches the query
// and those who matches only with the description
- QString normal, special;
- QHtmlStream sstream(&special), nstream(&normal);
+ TQString normal, special;
+ TQHtmlStream sstream(&special), nstream(&normal);
- // QMap iteration sorts wrt the key < operator
- // with QStrings, it means case insensitive sort
- QMap<QString, QString>::ConstIterator i;
+ // TQMap iteration sorts wrt the key < operator
+ // with TQStrings, it means case insensitive sort
+ TQMap<TQString, TQString>::ConstIterator i;
for (i = results.begin(); i != results.end(); ++i)
{
- const QString key = i.key();
- QHtmlStream* stream = &nstream;
+ const TQString key = i.key();
+ TQHtmlStream* stream = &nstream;
if (key == query)
stream = &sstream;
@@ -66,8 +66,8 @@ void Search::operator() (AptProtocol* slave, const QString& tag, const QString&
}
if (!special.isEmpty())
- *slave << QString("<table>") + special + QString("</table>\n<hr>\n");
- *slave << QString("<table>") + normal + QString("</table>");
+ *slave << TQString("<table>") + special + TQString("</table>\n<hr>\n");
+ *slave << TQString("<table>") + normal + TQString("</table>");
results.clear();
}